package com.bonus.material.repair.service;

import java.util.List;

import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.material.back.domain.vo.MaCodeVo;
import com.bonus.common.biz.domain.repair.RepairInputDetails;
import com.bonus.material.basic.domain.BmQrcodeInfo;
import com.bonus.material.repair.domain.RepairInputInfo;

/**
 * 修试后入库Service接口
 *
 * @author xsheng
 * @date 2024-10-16
 */
public interface IRepairInputDetailsService {
    /**
     * 查询修试后入库
     *
     * @param repairInputDetails 修试后入库主键
     * @return 修试后入库
     */
    public List<RepairInputInfo> selectRepairInputDetailsById(RepairInputDetails repairInputDetails);

    /**
     * 查询修试后入库列表
     *
     * @param repairInputDetails 修试后入库
     * @return 修试后入库集合
     */
    public List<RepairInputDetails> selectRepairInputDetailsList(RepairInputDetails repairInputDetails);

    /**
     * 新增修试后入库
     *
     * @param repairInputDetails 修试后入库
     * @return 结果
     */
    public int insertRepairInputDetails(RepairInputDetails repairInputDetails);

    /**
     * 修改修试后入库
     *
     * @param repairInputDetails 修试后入库
     * @return 结果
     */
    public int updateRepairInputDetails(RepairInputDetails repairInputDetails);

    /**
     * 批量删除修试后入库
     *
     * @param ids 需要删除的修试后入库主键集合
     * @return 结果
     */
    public int deleteRepairInputDetailsByIds(Long[] ids);

    /**
     * 删除修试后入库信息
     *
     * @param id 修试后入库主键
     * @return 结果
     */
    public int deleteRepairInputDetailsById(Long id);

    /**
     * 入库或批量入库操作
     * @param repairInputDetails
     * @return
     */
    AjaxResult warehouse(RepairInputDetails repairInputDetails);

    /**
     * 查询入库编码
     * @param mdCodeVo
     * @return
     */
    AjaxResult getCodeList(MaCodeVo mdCodeVo);

    /**
     * 修试入库驳回或批量驳回
     * @param repairInputDetails
     * @return
     */
    AjaxResult reject(RepairInputDetails repairInputDetails);

    /**
     * 根据二维码查询机具信息
     * @param bmQrcodeInfo
     * @return
     */
    AjaxResult getInfoByQrcode(BmQrcodeInfo bmQrcodeInfo);

    int sanInput(RepairInputDetails repairInputDetails);

    int sanQrBoxInput(RepairInputDetails repairInputDetails);
}
