package com.bonus.material.repair.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import cn.hutool.core.convert.Convert;
import com.bonus.common.biz.annotation.StoreLog;
import com.bonus.common.biz.config.ListPagingUtil;
import com.bonus.common.core.utils.ServletUtils;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.back.domain.vo.MaCodeVo;
import com.bonus.material.basic.domain.BmQrcodeInfo;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.common.biz.domain.repair.RepairInputDetails;
import com.bonus.material.repair.service.IRepairInputDetailsService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;

/**
 * 修试后入库Controller
 *
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "修试后入库接口")
@RestController
@RequestMapping("/repair_input_details")
public class RepairInputDetailsController extends BaseController {
    @Autowired
    private IRepairInputDetailsService repairInputDetailsService;

    /**
     * 查询修试后入库列表
     */
    @ApiOperation(value = "查询修试后入库列表")
    //@RequiresPermissions("repair:details:list")
    @GetMapping("/list")
    public AjaxResult list(RepairInputDetails repairInputDetails) {
        Integer pageIndex = Convert.toInt(ServletUtils.getParameter("pageNum"), 1);
        Integer pageSize = Convert.toInt(ServletUtils.getParameter("pageSize"), 10);
        List<RepairInputDetails> list = repairInputDetailsService.selectRepairInputDetailsList(repairInputDetails);
        return AjaxResult.success(ListPagingUtil.paging(pageIndex, pageSize, list));
    }

    /**
     * 导出修试后入库列表
     */
    @ApiOperation(value = "导出修试后入库列表")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:details:export")
    @SysLog(title = "修试后入库", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出修试后入库")
    @PostMapping("/export")
    public void export(HttpServletResponse response, RepairInputDetails repairInputDetails) {
        List<RepairInputDetails> list = repairInputDetailsService.selectRepairInputDetailsList(repairInputDetails);
        ExcelUtil<RepairInputDetails> util = new ExcelUtil<RepairInputDetails>(RepairInputDetails.class);
        util.exportExcel(response, list, "修试后入库数据");
    }

    /**
     * 获取修试后入库详细信息
     */
    @ApiOperation(value = "获取修试后入库详细信息")
    //@RequiresPermissions("repair:details:query")
    @GetMapping(value = "/getById")
    public AjaxResult getInfo(RepairInputDetails repairInputDetails) {
        return success(repairInputDetailsService.selectRepairInputDetailsById(repairInputDetails));
    }

    /**
     * 新增修试后入库
     */
    @ApiOperation(value = "新增修试后入库")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:details:add")
    @SysLog(title = "修试后入库", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增修试后入库")
    @PostMapping
    public AjaxResult add(@RequestBody RepairInputDetails repairInputDetails) {
        try {
            return toAjax(repairInputDetailsService.insertRepairInputDetails(repairInputDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改修试后入库
     */
    @ApiOperation(value = "修改修试后入库")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:details:edit")
    @SysLog(title = "修试后入库", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改修试后入库")
    @PutMapping
    public AjaxResult edit(@RequestBody RepairInputDetails repairInputDetails) {
        try {
            return toAjax(repairInputDetailsService.updateRepairInputDetails(repairInputDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除修试后入库
     */
    @ApiOperation(value = "删除修试后入库")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:details:remove")
    @SysLog(title = "修试后入库", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除修试后入库")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(repairInputDetailsService.deleteRepairInputDetailsByIds(ids));
    }

    /**
     * 入库或批量入库操作
     * @param repairInputDetails
     * @return
     */
    @ApiOperation(value = "入库或批量入库操作")
    @PreventRepeatSubmit
//    @RequiresPermissions("purchase:storage:add")
    @StoreLog(title = "修试后入库", module = "修试入库->修试后入库")
    @PostMapping("/warehouse")
    public AjaxResult warehouse(@RequestBody RepairInputDetails repairInputDetails) {
        return repairInputDetailsService.warehouse(repairInputDetails);
    }

    /**
     * 二维码出库：根据qrcode查询在库机具信息
     * @param bmQrcodeInfo
     * @return
     */
    @GetMapping("/getInfoByQrcode")
    public AjaxResult getInfoByQrcode(BmQrcodeInfo bmQrcodeInfo) {
        return repairInputDetailsService.getInfoByQrcode(bmQrcodeInfo);
    }

    /**
     * 查询修试待入库机具编码
     * @param mdCodeVo
     * @return
     */
    @ApiOperation(value = "查询修试待入库机具编码")
//    @RequiresPermissions("purchase:storage:add")
    @GetMapping("/getCodeList")
    public AjaxResult getCodeList(MaCodeVo mdCodeVo) {
        return repairInputDetailsService.getCodeList(mdCodeVo);
    }

    /**
     * 修试入库驳回或批量驳回
     * @param repairInputDetails
     * @return
     */
    @ApiOperation(value = "修试入库驳回或批量驳回")
    @PreventRepeatSubmit
//    @RequiresPermissions("purchase:storage:reject")
    @PostMapping("/reject")
    public AjaxResult reject(@RequestBody RepairInputDetails repairInputDetails) {
        return repairInputDetailsService.reject(repairInputDetails);
    }

    /**
     * 修试入库二维码扫描
     */
    @ApiOperation(value = "修试入库二维码扫描")
    @PreventRepeatSubmit
    @SysLog(title = "扫描入库", businessType = OperaType.UPDATE, logType = 1,module = "修试入库->增加库存")
    @PostMapping("/sanQrcodeInput")
    public AjaxResult sanQrcodeInput(@RequestBody RepairInputDetails repairInputDetails) {
        try {
            return toAjax(repairInputDetailsService.sanInput(repairInputDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修试入库二维码标准箱扫描
     */
    @ApiOperation(value = "修试入库二维码标准箱扫描")
    @PreventRepeatSubmit
    @SysLog(title = "修试入库二维码标准箱扫描", businessType = OperaType.UPDATE, logType = 1,module = "修试入库->增加库存")
    @PostMapping("/sanQrBoxInput")
    public AjaxResult sanQrBoxInput(@RequestBody RepairInputDetails repairInputDetails) {
        try {
            return toAjax(repairInputDetailsService.sanQrBoxInput(repairInputDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }
}
